@@ -332,7 +332,7 @@ public class DocumentTest {
 		assertTrue(fieldGroupBy != null);
 		assertThat(fieldGroupBy.get_name(), is("artist_id"));
 
-		LayoutGroup groupSecondaries = groupby.get_group_secondary_fields();
+		LayoutGroup groupSecondaries = groupby.get_secondary_fields();
 		assertTrue(groupSecondaries != null);
 	}
 
